<div align="center">

# ![Jobflow remote](doc/source/_static/img/jfr_logo.svg)

</div>

[![tests](https://img.shields.io/github/actions/workflow/status/Matgenix/jobflow-remote/testing.yml?branch=develop&label=tests)](https://github.com/Matgenix/jobflow-remote/actions?query=workflow%3Atesting)
[![code coverage](https://img.shields.io/codecov/c/gh/Matgenix/jobflow-remote)](https://codecov.io/gh/Matgenix/jobflow-remote)
[![pypi version](https://img.shields.io/pypi/v/jobflow-remote?color=blue)](https://pypi.org/project/jobflow-remote)
![supported python versions](https://img.shields.io/pypi/pyversions/jobflow-remote)

**[Full Documentation][docs]**

Jobflow Remote is a Python package to run [jobflow](https://materialsproject.github.io/jobflow) workflows on remote resources.

## Need help?

Ask questions about Jobflow Remote on the [Jobflow Remote support forum][help-forum].
If you've found an issue with jobflow-remote, please submit a bug report on [GitHub Issues][issues].

## What’s new?

Track changes to jobflow-remote through the [changelog][changelog].

## Contributing

We greatly appreciate any contributions in the form of a pull request.
Additional information on contributing to jobflow-remote can be found [here][contributing].
We maintain a list of all contributors [here][contributors].

### Code of conduct

Help us keep jobflow-remote open and inclusive.
Please read and follow our [Code of Conduct][codeofconduct].

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)

## License

jobflow-remote is released under a modified BSD license; the full text can be found [here][license].


## Citation

If you use Jobflow in your work, please cite it as follows:

- "Jobflow: Computational Workflows Made Simple", A.S. Rosen, M. Gallant, J. George, J. Riebesell, H. Sahasrabuddhe, J.X. Shen, M. Wen, M.L. Evans, G. Petretto, D. Waroquiers, G.‑M. Rignanese, K.A. Persson, A. Jain, A.M. Ganose, _Journal of Open Source Software_, 9(93), 5995 (2024) DOI: [10.21105/joss.05995](https://doi.org/10.21105/joss.05995)

## Acknowledgements

jobflow-remote is developed and maintained by Matgenix SRL.

A full list of all contributors can be found [here][contributors].

[help-forum]: https://github.com//Matgenix/jobflow-remote/issues
[issues]: https://github.com//Matgenix/jobflow-remote/issues
[installation]: https://github.com//Matgenix/jobflow-remote/blob/develop/INSTALL.md
[contributing]: https://github.com/Matgenix/jobflow-remote/blob/develop/CONTRIBUTING.md
[codeofconduct]: https://github.com/Matgenix/jobflow-remote/blob/develop/CODE_OF_CONDUCT.md
[changelog]: https://github.com//Matgenix/jobflow-remote/blob/develop/CHANGELOG.md
[contributors]: https://github.com/Matgenix/jobflow-remote/graphs/contributors
[license]: https://raw.githubusercontent.com/Matgenix/jobflow-remote/blob/develop/LICENSE
[docs]: https://Matgenix.github.io/jobflow-remote/
